@@ -3,9 +3,9 @@ context("Test LC_logit")
 # test if caculatins are correct ----
 test_that("Determine if LC_logit calculations are correct", {
   m <- LC_logit((response / total) ~ log10(dose), p = c(50),
-                 weights = total,
-                 data = lamprey_tox[lamprey_tox$nominal_dose != 0, ],
-                 subset = c(month == "May"))
+                weights = total,
+                data = lamprey_tox[lamprey_tox$nominal_dose != 0, ],
+                subset = c(month == "May"))
 
   expect_equal(m$dose, expected = 1.256, tolerance = 0.001)
   expect_equal(m$LCL, expected = 1.188, tolerance = 0.001)
@@ -31,9 +31,9 @@ test_that("Determine if LC_logit calculations are correct", {
 
 
   a <- LC_logit((response / total) ~ log10(dose), p = c(50),
-                 weights = total,
-                 data = lamprey_tox[lamprey_tox$nominal_dose != 0, ],
-                 subset = c(month == "August"))
+                weights = total,
+                data = lamprey_tox[lamprey_tox$nominal_dose != 0, ],
+                subset = c(month == "August"))
 
   expect_equal(a$dose, expected = 4.013, tolerance = 0.001)
   expect_equal(a$LCL, expected = 3.621, tolerance = 0.001)
@@ -58,10 +58,10 @@ test_that("Determine if LC_logit calculations are correct", {
   expect_equal(s$pgof_sig, expected = 0.656, tolerance = 0.001)
 
   mm <- LC_logit((response / total) ~ dose, p = c(50),
-                  weights = total,
-                  data = lamprey_tox[lamprey_tox$nominal_dose != 0, ],
-                  log_x = FALSE,
-                  subset = c(month == "May"))
+                 weights = total,
+                 data = lamprey_tox[lamprey_tox$nominal_dose != 0, ],
+                 log_x = FALSE,
+                 subset = c(month == "May"))
   expect_equal(mm$dose, expected = 1.279, tolerance = 0.001)
   expect_equal(mm$LCL, expected = 1.215, tolerance = 0.001)
   expect_equal(mm$UCL, expected = 1.335, tolerance = 0.001)
@@ -75,18 +75,18 @@ test_that("Determine if LC_logit calculations are correct", {
 # test if long and short outputs -----
 test_that("Determine if long and short outputs work", {
   ma <- LC_logit((response / total) ~ log10(dose), p = c(50),
-                  weights = total,
-                  data = lamprey_tox[lamprey_tox$nominal_dose != 0, ],
-                  subset = c(month == "May"),
-                  long_output = FALSE)
+                 weights = total,
+                 data = lamprey_tox[lamprey_tox$nominal_dose != 0, ],
+                 subset = c(month == "May"),
+                 long_output = FALSE)
   expect_equal(ncol(ma), 7)
   expect_equal(nrow(ma), 1)
 
   may <- LC_logit((response / total) ~ log10(dose), p = c(50),
-                   weights = total,
-                   data = lamprey_tox[lamprey_tox$nominal_dose != 0, ],
-                   subset = c(month == "May"),
-                   long_output = TRUE)
+                  weights = total,
+                  data = lamprey_tox[lamprey_tox$nominal_dose != 0, ],
+                  subset = c(month == "May"),
+                  long_output = TRUE)
   expect_equal(ncol(may), 19)
   expect_equal(nrow(may), 1)
 
@@ -95,10 +95,10 @@ test_that("Determine if long and short outputs work", {
 # test errors for not supplying weights ----
 test_that("test error for not supplying weights", {
 
-  expect_error(expect_warning(LC_logit((response / total) ~ log10(dose),
-                                        p = 50,
-                                        data = lamprey_tox,
-                                        subset = c(month == "May"))))
+  expect_warning(LC_logit(cbind(response, survive) ~ log10(dose),
+                          p = 50,
+                          data = lamprey_tox,
+                          subset = c(month == "May")))
 
 })
 
@@ -107,7 +107,7 @@ test_that("test error for not supplying weights", {
 test_that("LC_logit throws warning when p is not supplied", {
 
   expect_warning(LC_logit((response / total) ~ log10(dose),
-                           weights = total,
-                           data = lamprey_tox,
-                           subset = c(month == "May")))
+                          weights = total,
+                          data = lamprey_tox,
+                          subset = c(month == "May")))
 })
